<?php
/**
 * Recent Post Widgets.
 *
 * @package True News
 */
if ( !function_exists('true_news_recent_post_widgets') ) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function true_news_recent_post_widgets(){
        // Recent Post widget.
        register_widget('True_News_Sidebar_Recent_Post_Widget');
    }
endif;
add_action('widgets_init', 'true_news_recent_post_widgets');
// Recent Post widget
if ( !class_exists('True_News_Sidebar_Recent_Post_Widget') ) :
    /**
     * Recent Post.
     *
     * @since 1.0.0
     */
    class True_News_Sidebar_Recent_Post_Widget extends True_News_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'true_news_popular_post_widget',
                'description' => esc_html__('Displays post form selected category specific for popular post in sidebars.', 'true-news'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'true-news'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => esc_html__('Select Category:', 'true-news'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'true-news'),
                ),
                'enable_counter' => array(
                    'label' => esc_html__('Enable Counter:', 'true-news'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'post_number' => array(
                    'label' => esc_html__('Number of Posts:', 'true-news'),
                    'type' => 'number',
                    'default' => 4,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 9,
                ),
            );
            parent::__construct( 'true-news-popular-sidebar-layout', esc_html__('BP: Recent Post Widget', 'true-news'), $opts, array(), $fields );
        }
        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget( $args, $instance )
        {
            $true_news_default = true_news_get_default_theme_options();
            $ed_read_later_posts = get_theme_mod( 'ed_read_later_posts',$true_news_default['ed_read_later_posts'] );
            $params = $this->get_params( $instance );
            echo $args['before_widget'];
            if ( !empty( $params['title'] ) ) {
                echo $args['before_title'] . esc_html( $params['title'] ) . $args['after_title'];
            }
            $qargs = array(
                'posts_per_page' => absint( $params['post_number'] ),
                'no_found_rows' => true,
            );
            if ( absint( $params['post_category'] ) > 0 ) {
                $qargs['category'] = absint($params['post_category']);
            }
            $all_posts = get_posts( $qargs );
            $count = 1;
            
            if ( !empty( $all_posts ) ) : ?>
            <div class="widget-content twp-recent-widget">
                <ul class="twp-widget-list recent-widget-list">
                <?php foreach ( $all_posts as $key => $twp_post ) : ?>
                    <?php setup_postdata($twp_post); ?>
                    <li>
                        <article class="article-list">
                            <div class="twp-row twp-row-small">

                               
                                <?php if( has_post_thumbnail() ): ?>
                                    <div class="column column-4">
                                        <div class="article-image">
                                            <?php true_news_post_thumbnail('true-news-small','',true,$atag = true); ?>

                                            <?php if ( true === $params['enable_counter'] ) { ?>
                                                <div class="trend-item">
                                                    <span class="number"> <?php echo $count; ?></span>
                                                </div>
                                            <?php } ?>

                                        </div>
                                    </div>
                                <?php endif; ?>


                                <div class="<?php if ( !has_post_thumbnail() ) { echo 'column column-10'; }else{ echo 'column column-6'; } ?>">
                                    <div class="article-body">
                                        <div class="entry-meta entry-meta-1">
                                            <span class="posted-on">
                                                <?php true_news_entry_meta( $hide_post_author_avatar = 'yes', $hide_post_author= 'yes', $hide_post_date= 'no', $text = false ); ?>
                                            </span>
                                        </div>
                                        <h3 class="entry-title entry-title-small">
                                            <a href="<?php the_permalink(); ?>">
                                                <?php the_title(); ?>
                                            </a>
                                            <?php if( $ed_read_later_posts ){ true_news_add_read_later_post_html( get_the_ID() ); } ?>
                                        </h3>
                                    </div>
                                </div>
                            </div>
                        </article>
                    </li>
                <?php 
                $count++;
                endforeach; ?>
                </ul>
            </div>
            <?php wp_reset_postdata(); ?>
        <?php endif; ?>
            <?php echo $args['after_widget'];
        }
    }
endif;